@@ -34,7 +34,7 @@ import shutil
 import subprocess
 import sys
 from tempfile import TemporaryDirectory
-from typing import Optional, Tuple, List, Dict, Any, Callable
+from typing import Optional, Tuple, List, Dict, Any, Callable, cast
 from urllib.parse import urlparse
 
 
@@ -82,6 +82,7 @@ from ognibuild.fix_build import iterate_with_build_fixers, BuildFixer
 from ognibuild.session import SessionSetupFailure, Session
 from ognibuild.session.plain import PlainSession
 from ognibuild.session.schroot import SchrootSession
+from ognibuild.session.unshare import UnshareSession
 from ognibuild.requirements import (
     Requirement,
     )
@@ -96,6 +97,7 @@ from ognibuild.debian.upstream_deps import get_project_wide_deps
 from ognibuild.vcs import dupe_vcs_tree
 
 from upstream_ontologist.guess import (
+    UpstreamDatum,
     guess_upstream_info,
     summarize_upstream_metadata,
 )
@@ -608,8 +610,8 @@ def process_golang(es, session, wt, subpath, debian_path, upstream_version,
     return control
 
 
-def process_r(es, session, wt, subpath, debian_path, metadata,
-              upstream_version, compat_release, buildsystem,
+def process_r(es, session, wt, subpath, debian_path,
+              upstream_version, metadata, compat_release, buildsystem,
               buildsystem_subpath, kickstart_from_dist):
     kickstart_from_dist(wt, subpath)
     control = es.enter_context(ControlEditor.create(
@@ -623,7 +625,7 @@ def process_r(es, session, wt, subpath, debian_path, metadata,
     else:
         archive = 'other'
 
-    source["Source"] = "r-%s-%s" % (archive, metadata['Name'].lower())
+    source["Source"] = "r-{}-{}".format(archive, metadata['Name'].lower())
     source["Rules-Requires-Root"] = "no"
     source["Build-Depends"] = "dh-r, r-base-dev"
     source["Standards-Version"] = latest_standards_version()
@@ -637,7 +639,7 @@ def process_r(es, session, wt, subpath, debian_path, metadata,
     # For now, just assume a single binary package that is
     # architecture-dependent.
     control.add_binary({
-        "Package": "r-%s-%s" % (archive, metadata['Name'].lower()),
+        "Package": "r-{}-{}".format(archive, metadata['Name'].lower()),
         "Architecture": 'any',
         'Depends': '${R:Depends}, ${shlibs:Depends}, ${misc:Depends}',
         'Recommends': '${R:Recommends}',
@@ -893,6 +895,7 @@ async def find_wnpp_bugs_harder(source_name, upstream_name):
 
 def debianize(  # noqa: C901
     wt: WorkingTree, subpath: str,
+    *,
     upstream_branch: Optional[Branch], upstream_subpath: Optional[str],
     use_inotify: Optional[bool] = None,
     diligence: int = 0,
@@ -906,6 +909,7 @@ def debianize(  # noqa: C901
     consult_external_directory: bool = True,
     verbose: bool = False,
     schroot: Optional[str] = None,
+    unshare: Optional[str] = None,
     create_dist=None,
     committer: Optional[str] = None,
     upstream_version_kind: str = "auto",
@@ -925,7 +929,7 @@ def debianize(  # noqa: C901
             and not force_new_directory):
         raise DebianDirectoryExists(wt.abspath(subpath))
 
-    metadata_items = []
+    metadata_items: List[UpstreamDatum] = []
     if metadata is None:
         metadata = {}
     else:
@@ -956,11 +960,15 @@ def debianize(  # noqa: C901
             if not wt.is_versioned(debian_path):
                 wt.add(debian_path)
 
-            if schroot is None:
-                session = PlainSession()
-            else:
+            session: Session
+            if schroot:
                 logging.info('Using schroot %s', schroot)
                 session = SchrootSession(schroot)
+            elif unshare:
+                logging.info('Using tarball %s for unshare', unshare)
+                session = UnshareSession.from_tarball(unshare)
+            else:
+                session = PlainSession()
 
             if upstream_branch:
                 upstream_source = UpstreamBranchSource.from_branch(
@@ -1105,7 +1113,8 @@ def debianize(  # noqa: C901
             )
 
             if (requirement and requirement.family == 'apt' and
-                    not requirement.satisfied_by(control.binaries, version)):
+                    not cast(AptRequirement, requirement).satisfied_by(
+                        control.binaries, version)):
                 logging.warning(
                     'Debianized package (binary packages: %r), version %s '
                     'did not satisfy requirement %r. '
@@ -1254,7 +1263,7 @@ class DebianizeFixer(BuildFixer):
         return "debianize fixer"
 
     def __repr__(self):
-        return "%s(%r, %r)" % (
+        return "{}({!r}, {!r})".format(
             type(self).__name__, self.vcs_directory,
             self.apt_repo)
 
@@ -1265,6 +1274,7 @@ class DebianizeFixer(BuildFixer):
                  upstream_version_kind="release",
                  debian_revision="1",
                  schroot=None,
+                 unshare=None,
                  consult_external_directory=True,
                  use_inotify=None,
                  create_dist=None,
@@ -1283,6 +1293,7 @@ class DebianizeFixer(BuildFixer):
         self.debian_revision = debian_revision
         self.consult_external_directory = consult_external_directory
         self.schroot = schroot
+        self.unshare = unshare
         self.use_inotify = use_inotify
         self.create_dist = create_dist
         self.compat_release = compat_release
@@ -1339,7 +1350,8 @@ class DebianizeFixer(BuildFixer):
         new_subpath = ''
         debianize(
             new_wt, new_subpath,
-            upstream_branch, upstream_info.branch_subpath or '',
+            upstream_branch=upstream_branch,
+            upstream_subpath=(upstream_info.branch_subpath or ''),
             use_inotify=self.use_inotify,
             diligence=self.diligence,
             create_dist=self.create_dist,
@@ -1351,6 +1363,7 @@ class DebianizeFixer(BuildFixer):
             compat_release=self.compat_release,
             consult_external_directory=self.consult_external_directory,
             verbose=self.verbose, schroot=self.schroot,
+            unshare=self.unshare,
             debian_revision=self.debian_revision,
             upstream_version=upstream_info.version,
             upstream_version_kind=self.upstream_version_kind,
@@ -1451,6 +1464,9 @@ def main(argv=None):  # noqa: C901
     parser.add_argument(
         "--schroot", type=str,
         help="Schroot to use for building and apt archive access")
+    parser.add_argument(
+        "--unshare", type=str,
+        help="Unshare tarball to use for building and apt archive access")
     parser.add_argument(
         "--build-command",
         type=str,
@@ -1522,6 +1538,11 @@ def main(argv=None):  # noqa: C901
         loglevel = logging.INFO
     logging.basicConfig(level=loglevel, format='%(message)s')
 
+    logging.warning(
+        'debianize is experimental and often generates packaging '
+        'that is incomplete or does not build as-is. '
+        'If you encounter issues, please consider filing a bug.')
+
     compat_release = args.compat_release
     if compat_release is None:
         import distro_info
@@ -1545,6 +1566,8 @@ def main(argv=None):  # noqa: C901
     else:
         create_dist = None
 
+    metadata = {}
+
     # For now...
     if args.upstream:
         try:
@@ -1553,6 +1576,8 @@ def main(argv=None):  # noqa: C901
         except NotBranchError as e:
             logging.fatal('%s: not a valid branch: %s', args.upstream, e)
             return 1
+        metadata['Repository'] = UpstreamDatum(
+            'Repository', args.upstream, certainty='confident')
     elif args.debian_binary:
         apt_requirement = AptRequirement.from_str(args.debian_binary)
         upstream_info = find_apt_upstream(apt_requirement)
@@ -1565,11 +1590,16 @@ def main(argv=None):  # noqa: C901
             'Found relevant upstream branch at %s', upstream_info.branch_url)
         upstream_branch = Branch.open(upstream_info.branch_url)
         upstream_subpath = upstream_info.branch_subpath
+
+        metadata['Repository'] = UpstreamDatum(
+            'Repository', upstream_info.branch_url, certainty='confident')
     else:
-        if not wt.has_filename(os.path.join(subpath, 'debian')):
+        if wt.has_filename(os.path.join(subpath, 'debian')):
             report_fatal(
                 code='debian-directory-exists',
-                description="%s: A debian directory already exists. " % e.path,
+                description=(
+                    f"{wt.abspath(subpath)}: "
+                    "A debian directory already exists."),
                 hint=("Run lintian-brush instead or "
                       "specify --force-new-directory."),
             )
@@ -1586,12 +1616,12 @@ def main(argv=None):  # noqa: C901
         use_packaging_branch(
             wt, args.debian_branch % {'vendor': get_vendor_name().lower()})
 
-    use_inotify = ((False if args.disable_inotify else None))
+    use_inotify = (False if args.disable_inotify else None)
     with wt.lock_write():
         try:
             debianize_result = debianize(
                 wt, subpath,
-                upstream_branch, upstream_subpath,
+                upstream_branch=upstream_branch, upstream_subpath=upstream_subpath,
                 use_inotify=use_inotify,
                 diligence=args.diligence,
                 trust=args.trust,
@@ -1603,10 +1633,12 @@ def main(argv=None):  # noqa: C901
                 consult_external_directory=args.consult_external_directory,
                 verbose=args.verbose,
                 schroot=args.schroot,
+                unshare=args.unshare,
                 upstream_version_kind=args.upstream_version_kind,
                 debian_revision=args.debian_revision,
                 create_dist=create_dist,
                 upstream_version=args.upstream_version,
+                metadata=metadata,
             )
         except PackageVersionNotPresent:
             if args.upstream_version:
@@ -1614,6 +1646,7 @@ def main(argv=None):  # noqa: C901
                     'requested-version-missing',
                     'Requested version %s not present upstream' %
                     args.upstream_version)
+                return 1
             else:
                 # For now
                 raise
@@ -1672,11 +1705,16 @@ def main(argv=None):  # noqa: C901
         args.iterate_fix = True
 
     if args.iterate_fix:
-        if args.schroot is None:
-            session = PlainSession()
-        else:
+        session: Session
+
+        if args.schroot:
             logging.info('Using schroot %s', args.schroot)
             session = SchrootSession(args.schroot)
+        elif args.unshare:
+            logging.info('Using tarball %s for unshare', args.unshare)
+            session = UnshareSession.from_tarball(args.unshare)
+        else:
+            session = PlainSession()
 
         with contextlib.ExitStack() as es:
             es.enter_context(session)
@@ -1733,7 +1771,8 @@ def main(argv=None):  # noqa: C901
                                 upstream_version_kind=(
                                     args.upstream_version_kind),
                                 debian_revision=args.debian_revision,
-                                schroot=args.schroot, use_inotify=use_inotify,
+                                schroot=args.schroot,
+                                unshare=args.unshare, use_inotify=use_inotify,
                                 consult_external_directory=(
                                     args.consult_external_directory),
                                 create_dist=create_dist,
@@ -1749,7 +1788,7 @@ def main(argv=None):  # noqa: C901
                 elif len(e.phase) == 1:
                     phase = e.phase[0]
                 else:
-                    phase = '%s (%s)' % (e.phase[0], e.phase[1])
+                    phase = f'{e.phase[0]} ({e.phase[1]})'
                 logging.fatal('Error during %s: %s', phase, e.error)
                 return 1
             except UnidentifiedDebianBuildError as e:
@@ -1758,7 +1797,7 @@ def main(argv=None):  # noqa: C901
                 elif len(e.phase) == 1:
                     phase = e.phase[0]
                 else:
-                    phase = '%s (%s)' % (e.phase[0], e.phase[1])
+                    phase = f'{e.phase[0]} ({e.phase[1]})'
                 logging.fatal('Error during %s: %s', phase, e.description)
                 return 1
             except DebianizedPackageRequirementMismatch as e:
