@@ -48,6 +48,11 @@ from . import (
 from .gpg import fetch_keys
 
 
+# TODO(jelmer): Vary this depending on whether a new watch file was added or an
+# existing one was fixed?
+WATCH_FIX_VALUE = 60
+
+
 @dataclass
 class WatchCandidate:
 
@@ -178,8 +183,8 @@ def candidates_from_setup_py(
                 if d["packagetype"] == "sdist"
             ]
     filename_regex = (
-            r"%(project)s-(.+)\.(?:zip|tgz|tbz|txz|(?:tar\.(?:gz|bz2|xz)))" % {
-                "project": project})
+        r"{project}-(.+)\.(?:zip|tgz|tbz|txz|(?:tar\.(?:gz|bz2|xz)))".format(
+            project=project))
     opts = []
     # TODO(jelmer): Set uversionmangle?
     # opts.append('uversionmangle=s/(rc|a|b|c)/~$1/')
@@ -189,10 +194,10 @@ def candidates_from_setup_py(
                 certainty = "certain"
                 if has_sig:
                     opts.append("pgpsigurlmangle=s/$/.asc/")
-    url = r"https://pypi.debian.net/%(project)s/%(fname_regex)s" % {
-        "project": project,
-        "fname_regex": filename_regex,
-    }
+    url = r"https://pypi.debian.net/{project}/{fname_regex}".format(
+        project=project,
+        fname_regex=filename_regex,
+    )
     # TODO(jelmer): Add pgpsigurlmangle if has_sig==True
     w = Watch(url, opts=opts)
     yield WatchCandidate(w, "pypi", certainty=certainty, preference=1)
@@ -223,7 +228,7 @@ def find_candidates(path, good_upstream_versions, net_access=False):
 def candidates_from_upstream_metadata(
         path: str, good_upstream_versions: Set[str], net_access: bool = False):
     try:
-        with open(path, "r") as f:
+        with open(path) as f:
             inp = f.read()
     except FileNotFoundError:
         pass
@@ -313,10 +318,10 @@ def guess_github_watch_entry(
     (username, project) = parsed_url.path.strip("/").split("/")
     if project.endswith(".git"):
         project = project[:-4]
-    download_url = "https://github.com/%(user)s/%(project)s/tags" % {
-        "user": username,
-        "project": project,
-    }
+    download_url = "https://github.com/{user}/{project}/tags".format(
+        user=username,
+        project=project,
+    )
     matching_pattern = r".*\/%s\.tar\.gz" % version_pattern
     opts = [
         r"filenamemangle=s/%(pattern)s/%(project)s-$1\.tar\.gz/"
@@ -472,13 +477,13 @@ def verify_watch_entry(
     if expected_versions is None:
         return WatchEntryVerificationStatus(entry, releases=releases)
 
-    found_versions = set([str(r.version) for r in releases])
+    found_versions = {str(r.version) for r in releases}
     missing_versions = set(expected_versions) - found_versions
     return WatchEntryVerificationStatus(
         entry, releases=releases, missing_versions=missing_versions)
 
 
-def report_fatal(code: str, description: str, context=None) -> None:
+def report_fatal(code: str, description: str, context=None, hint=None) -> None:
     if os.environ.get('SVP_API') == '1':
         with open(os.environ['SVP_RESULT'], 'w') as f:
             json.dump({
@@ -486,6 +491,8 @@ def report_fatal(code: str, description: str, context=None) -> None:
                 'description': description,
                 'context': context}, f)
     logging.fatal('%s', description)
+    if hint:
+        logging.info('%s', hint)
 
 
 def verify_watch_file(watch_file, source_package, expected_versions):
@@ -497,7 +504,7 @@ def verify_watch_file(watch_file, source_package, expected_versions):
 
 
 def svp_context(status, site):
-    return {
+    return [{
         'entries': {
             'text': str(entry_status.entry),
             'site': entry_site,
@@ -508,8 +515,23 @@ def svp_context(status, site):
             },
             'missing_versions':
                 [str(x) for x in entry_status.missing_versions]
-        } for entry_status, entry_site in zip(status or [], site or [])
-    }
+        }
+    } for entry_status, entry_site in zip(
+        status or [], site or [None] * len(status or []))]
+
+
+_changelog_policy_noted = False
+
+
+def _note_changelog_policy(policy, msg):
+    global _changelog_policy_noted
+    if not _changelog_policy_noted:
+        if policy:
+            extra = "Specify --no-update-changelog to override."
+        else:
+            extra = "Specify --update-changelog to override."
+        logging.info("%s %s", msg, extra)
+    _changelog_policy_noted = True
 
 
 def main():  # noqa: C901
@@ -521,6 +543,7 @@ def main():  # noqa: C901
     import breezy.git  # noqa: E402
     import breezy.bzr  # noqa: E402
 
+    from breezy.commit import NullCommitReporter, PointlessCommit
     from breezy.workingtree import WorkingTree
     from breezy.workspace import (
         check_clean_tree,
@@ -573,8 +596,8 @@ def main():  # noqa: C901
         "--debug", help="Describe all considered changes.", action="store_true"
     )
     parser.add_argument(
-        "--verify", action="store_true",
-        help="Verify that the new watch file works")
+        "--no-verify", action="store_true",
+        help="Do not verify that the new watch file works")
     parser.add_argument(
         "--disable-net-access",
         help="Do not probe external services.",
@@ -619,8 +642,10 @@ def main():  # noqa: C901
 
         good_upstream_versions = set()
 
-        with open('debian/changelog', 'r') as f:
-            cl = Changelog(f)
+        changelog_path = os.path.join(subpath, "debian/changelog")
+
+        with wt.get_file(changelog_path) as f:
+            cl = Changelog(f, max_blocks=1)
             for entry in cl:
                 uv = strip_dfsg_suffix(entry.version.upstream_version)
                 if get_snapshot_revision(uv) is not None:
@@ -633,7 +658,8 @@ def main():  # noqa: C901
         status = None
         try:
             with WatchEditor(allow_reformatting=allow_reformatting,
-                             allow_missing=False) as updater:
+                             allow_missing=False,
+                             ) as updater:
                 try:
                     status = verify_watch_file(
                         updater.watch_file, package, expected_versions)
@@ -641,10 +667,16 @@ def main():  # noqa: C901
                         WatchEntryVerificationFailure):
                     status = [None]
                 if status and all(status):
+                    hint = (
+                        'Releases {} can be found with watch entry {}'.format(
+                            ', '.join(sorted(list(
+                                status[0].releases.keys()), reverse=True)),
+                            status[0].entry))
                     report_fatal(
                         'nothing-to-do',
                         'Existing watch file has valid entries',
-                        context=svp_context(status))
+                        context=svp_context(status, site=None),
+                        hint=hint)
                     return 0
                 fix_watch_issues(updater)
                 try:
@@ -668,8 +700,12 @@ def main():  # noqa: C901
                     updater.watch_file.entries = [candidates[0].watch]
                     site = [candidates[0].site]
                     status = None
+                    summary = (
+                        f'Update watch file from {site[0]}, '
+                        'since it was broken')
                 else:
                     site = None
+                    summary = 'Fixed watch file'
         except FileNotFoundError:
             candidates = find_candidates(
                 '.', good_upstream_versions,
@@ -686,43 +722,80 @@ def main():  # noqa: C901
             with open('debian/watch', 'w') as f:
                 wf.dump(f)
             status = None
+            summary = 'Added watch file'
         except FormattingUnpreservable as e:
             report_fatal('formatting-unpreservable',
                          "Unable to preserve formatting of %s" % e.path)
             return 1
 
-    if args.verify and status is None:
-        with WatchEditor() as updater:
-            try:
-                status = verify_watch_file(
-                    updater.watch_file, package, expected_versions)
-            except WatchEntryVerificationFailure as e:
-                report_fatal(
-                    'verification-failed',
-                    'Unable to verify watch entry: %s'
-                    % e)
-                return 1
-            except TemporaryWatchEntryVerficationError as e:
-                report_fatal(
-                    'temporary-verification-error',
-                    'Unable to verify watch entry: %s'
-                    % e)
-                return 1
-            if not status or not all(status):
-                report_fatal(
-                    'verification-failed',
-                    'Unable to watch entries; missing versions: %r'
-                    % status[0].missing_versions,
-                    context=svp_context(status, site))
-                return 1
+        if not args.no_verify and status is None:
+            with WatchEditor() as updater:
+                try:
+                    status = verify_watch_file(
+                        updater.watch_file, package, expected_versions)
+                except WatchEntryVerificationFailure as e:
+                    report_fatal(
+                        'verification-failed',
+                        'Unable to verify watch entry: %s'
+                        % e)
+                    return 1
+                except TemporaryWatchEntryVerficationError as e:
+                    report_fatal(
+                        'temporary-verification-error',
+                        'Unable to verify watch entry: %s'
+                        % e)
+                    return 1
+                if not status or not all(status):
+                    report_fatal(
+                        'verification-failed',
+                        'Unable to watch entries; missing versions: %r'
+                        % status[0].missing_versions,
+                        context=svp_context(status, site))
+                    return 1
+
+        specific_files = updater.changed_files
+
+        if update_changelog is None:
+            from .detect_gbp_dch import guess_update_changelog
+
+            dch_guess = guess_update_changelog(
+                wt, os.path.join(subpath, 'debian'), cl)
+            if dch_guess:
+                update_changelog = dch_guess.update_changelog
+                _note_changelog_policy(update_changelog, dch_guess.explanation)
+            else:
+                # Assume we should update changelog
+                update_changelog = True
+
+        if update_changelog:
+            from .changelog import add_changelog_entry
+
+            # TODO(jelmer): Add note here about having verified watch file?
+            add_changelog_entry(wt, changelog_path, [summary])
+            if specific_files:
+                specific_files.append(changelog_path)
+
+        committer = get_committer(wt)
+
+        with suppress(PointlessCommit):
+            wt.commit(
+                specific_files=specific_files,
+                message=summary,
+                allow_pointless=False,
+                reporter=NullCommitReporter(),
+                committer=committer,
+            )
 
     if os.environ.get("SVP_API") == "1":
         with open(os.environ["SVP_RESULT"], "w") as f:
             json.dump({
-                "description": "Update watch file.",
+                "description": summary,
                 "context": svp_context(status, site),
+                "value": WATCH_FIX_VALUE,
             }, f)
 
+    logging.info('%s', summary)
+
     return 0
 
 
